\name{anm}
\alias{anm}
\title{The Analog method}
\description{
\emph{anm} is used to compute the analog method.
}
\usage{
anm(formula,data,weights=NULL,cross.valid=NULL)
}

\arguments{
    \item{formula}{a symbolic description of the model to be fit.}
    \item{data}{the data.frame containing the variables in the model.}
    \item{weights}{an optional matrix of weights to be used in the fitting process.}
    \item{cross.valid}{an optional matrix of booleans. If not specified, a cross validation is used in the fitting process.}
          }
\details{Models for \emph{anm} are specified symbolically. A typical model has the form \emph{predictand ~ terms} where \emph{terms} is a series of predictors whose specification can be of the for \emph{first + second}.
\link{anm} calls the lower level function \link[clim.pact]{anm.fit}.
}
\value{An object of class "anm".
An object of class "anm" is a list containing the following components: 
\item{coefficients}{a vector containing the values for the principal components corresponding to the maximum among observations.}
\item{contrasts}{(not used).}
\item{call}{the matched call.}
\item{terms}{the terms object used.}
\item{model}{the model frame used.}
\item{x}{the matrix used for predictors.}
\item{y}{the predictand.}
\item{weights}{the matrix of weights.}
\item{cross.valid}{equals to True if the cross.validation will be used for the fitting process.}
\item{data}{the input data.frame.}
}
\references{URL \url{http://www.R-project.org/}}
\author{Alexandra Imbert}
\seealso{link{predict.anm}, link{stepANM}}
\examples{
library(survival)
library(clim.pact)
data(temp.era) 
data(susendal) 
y<-susendal$V6 # temperatures
X<- eof$PC[,c(1,2)]
calibration <- c(susendal$V4>1979 & susendal$V4<1990 & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
evaluation <- c((susendal$V4>1990 & susendal$V4<1993 | susendal$V4==1990) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
y.calib <- y[calibration]
y.eval <- y[evaluation]
eof.calib <- c(eof$yy>1979 & eof$yy<1990)
eof.eval <- c(eof$yy> 1990 & eof$yy<1993| eof$yy==1990)
period <- c(calibration, evaluation)
y.period <- y[(susendal$V4>1979 & susendal$V4<1993) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12)]
test.data <-data.frame(y=y.period,
                       X1=X[eof$yy< 1993 & eof$yy> 1979,1],
                       X2=X[eof$yy< 1993 & eof$yy> 1979,2],
                       yy=eof$yy[eof.calib | eof.eval],
                       mm=eof$mm[eof.calib | eof.eval],
                       dd=eof$dd[eof.calib | eof.eval])
anm(y ~ X1 + X2,data=test.data)
}
\keyword{models}





\eof
\name{anm.fit}
\alias{anm.fit}
\title{Support function for anm}
\description{Basic computing engine called by \link{anm} to implement the analog method. This should usually not be used directly. 
}
\usage{
anm.fit(x, y, tol = 1e-07, ...)
}
\arguments{
    \item{x}{design matrix of dimension n * p.}
    \item{y}{vector of observations of length n.}
    \item{tol}{if equal to 1, information is printed during the running of step.}
    \item{cross.valid}{tolerance for the qr decomposition. Default is 1e-7.}
    \item{...}{currently disregarded.}
          }
\value{
 A list with components
 \item{coefficients}{vector containing the highest value among observations and the values of the predictors at this date.}
 \item{residuals}{\emph{n} vector.}
 \item{fitted.values}{\emph{n} vector.}
 \item{effects}{\emph{n} vector.}
 \item{rank}{integer, giving the rank.}
 \item{df.residual}{degrees of freedom of residuals.}
 \item{qr}{the QR decomposition, see \link{qr}.}
}
\references{URL \url{http://www.R-project.org/}}
\author{Alexandra Imbert}
\seealso{\link{anm}, \link{predict.anm}}
\keyword{models}




\eof
\name{eof}
\alias{eof}
\title{Daily common EOF.}
\description{See \link[clim.pact]{EOF}}
\keyword{datasets}
  
\eof
\name{plotANM}
\alias{plotANM}
\title{Plot Diagnostics for an anm Object.}
\description{Three plots are provided: a plot of the minimum distances versus time, a plot comparing the analogs from \link[clim.pact]{EOF} and observations and a plot of errors versus time.}
\usage{
plotANM(x,tmp,station,eof.file,leps)
}
\arguments{
    \item{x}{the anm object inheriting from \link{anm} routine and for which prediction is desired.}
    \item{tmp}{True if the analysis is on temperature, False if on precipitation.}
    \item{station}{the name of the station.}
    \item{eof.file}{string giving the name of the eof file used for the study.}
    \item{leps}{if true, postscripts are created for the plots.}
          }
\author{Alexandra Imbert}
\seealso{\link{anm}, \link{stepANM}, \link{predict.anm}, \link{print.anm}}
\examples{
library(survival)
library(clim.pact)
data(temp.era) 
data(susendal)
y<-susendal$V6 # temperatures
X<- eof$PC[,c(1,2)]
calibration <- c(susendal$V4>1979 & susendal$V4<1990 & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
evaluation <- c((susendal$V4>1990 & susendal$V4<1993 | susendal$V4==1990) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
y.calib <- y[calibration]
y.eval <- y[evaluation]
eof.calib <- c(eof$yy>1979 & eof$yy<1990)
eof.eval <- c(eof$yy> 1990 & eof$yy<1993| eof$yy==1990)
period <- c(calibration, evaluation)
y.period <- y[(susendal$V4>1979 & susendal$V4<1993) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12)]
test.data <-data.frame(y=y.period,
                       X1=X[eof$yy< 1993 & eof$yy> 1979,1],
                       X2=X[eof$yy< 1993 & eof$yy> 1979,2],
                       yy=eof$yy[eof.calib | eof.eval],
                       mm=eof$mm[eof.calib | eof.eval],
                       dd=eof$dd[eof.calib | eof.eval])
test.anm<-anm(y ~ X1 + X2,data=test.data)
plotANM(test.anm,TRUE,"Susendal","eof_ERA-15_TEM_16E31E-64N73N_DJF",FALSE)
}
\keyword{models}


\eof
\name{predict.anm}
\alias{predict.anm}
\title{Predict method for anm objects.}
\description{
Returns the predicted values based on the \link{anm} object.
}
\usage{
predict.anm(object,newdata=NULL,se.fit=FALSE, ...)
}
\arguments{
    \item{object}{the anm object inheriting from \link{anm} routine.}
    \item{newdata}{an optional independant data. If specified, only the vector of predictions is returned.}
    \item{se.fit}{if false, only the vector of predictions is returned.}
    \item{...}{further arguments passed to or from other methods.}
          }
\value{
 A list with components
 \item{problem.dimension}{the number of predictor variables.} 
 \item{period.length}{the time period.} 
 \item{d.min}{the vector of minimum distances.}
 \item{date.min}{the vector containing the dates corresponding to the minimum distances.}
 \item{analog}{the vector of predictions.}
 \item{maxi.anlg}{monthly maxima values of predictions.}
 \item{mini.anlg}{monthly minima values of predictions.}
 \item{error}{vector of errors between predictions and observations at each date.}
 \item{correlation}{correlation coefficient between predictions and observations.}
 \item{rmse}{root mean square errors between predictions and observations.}
}
\references{URL \url{http://www.R-project.org/}}
\author{R.E. Benestad and Alexandra Imbert}
\seealso{\link{anm}, \link{stepANM}}
\examples{
library(survival)
library(clim.pact)
data(temp.era)
data(susendal)
y<-susendal$V6 # temperatures
X<- eof$PC[,c(1,2)]
calibration <- c(susendal$V4>1979 & susendal$V4<1990 & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
evaluation <- c((susendal$V4>1990 & susendal$V4<1993 | susendal$V4==1990) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
y.calib <- y[calibration]
y.eval <- y[evaluation]
eof.calib <- c(eof$yy>1979 & eof$yy<1990)
eof.eval <- c(eof$yy> 1990 & eof$yy<1993| eof$yy==1990)
period <- c(calibration, evaluation)
y.period <- y[(susendal$V4>1979 & susendal$V4<1993) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12)]
test.data <-data.frame(y=y.period,
                       X1=X[eof$yy< 1993 & eof$yy> 1979,1],
                       X2=X[eof$yy< 1993 & eof$yy> 1979,2],
                       yy=eof$yy[eof.calib | eof.eval],
                       mm=eof$mm[eof.calib | eof.eval],
                       dd=eof$dd[eof.calib | eof.eval])
test.anm<-anm(y ~ X1 + X2,data=test.data)
res <- predict.anm(test.anm)
}
\keyword{models}



\eof
\name{print.anm}
\alias{print.anm}
\title{Print some components of an anm object.}
\description{Prints the coefficients of an \link{anm} object.
}
\usage{
print.anm(x, digits = max(3, getOption("digits") - 3), ...)
}
\arguments{
    \item{x}{the \link{anm} object.}
    \item{digits}{the vector defining the format of printing.}
    \item{...}{currently disregarded.}
          }
\references{URL \url{http://www.R-project.org/}}
\author{Alexandra Imbert}
\seealso{\link{anm}, \link{predict.anm}}
\examples{
library(survival)
library(clim.pact)
data(susendal)
data(temp.era)
y<-susendal$V6 # temperatures
X<- eof$PC[,c(1,2)]
calibration <- c(susendal$V4>1979 & susendal$V4<1990 & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
evaluation <- c((susendal$V4>1990 & susendal$V4<1993 | susendal$V4==1990) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
y.calib <- y[calibration]
y.eval <- y[evaluation]
eof.calib <- c(eof$yy>1979 & eof$yy<1990)
eof.eval <- c(eof$yy> 1990 & eof$yy<1993| eof$yy==1990)
period <- c(calibration, evaluation)
y.period <- y[(susendal$V4>1979 & susendal$V4<1993) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12)]
test.data <-data.frame(y=y.period,
                       X1=X[eof$yy< 1993 & eof$yy> 1979,1],
                       X2=X[eof$yy< 1993 & eof$yy> 1979,2],
                       yy=eof$yy[eof.calib | eof.eval],
                       mm=eof$mm[eof.calib | eof.eval],
                       dd=eof$dd[eof.calib | eof.eval])
test.anm<-anm(y ~ X1 + X2,data=test.data)
print.anm(test.anm)
}
\keyword{models}

\eof
\name{stepANM}
\alias{stepANM}
\title{Choose a model by the analog method in a stepwise algorithm}
\description{Performs the analog method step by step to select a model and plots on the same graph both correlation and rmse at each step.
}
\usage{
stepANM(anm.obj,trace=1,steps=8)
}
\arguments{
    \item{anm.obj}{the anm object inheriting from \link{anm} routine.}
    \item{trace}{if equal to 1, information is printed during the running of the stepwise algorithm.}
    \item{steps}{maximum number of steps, forced to the number of predictor variables if \emph{steps} exceeds it.}
          }
\value{
 A list with components
 \item{Call}{the matched call.}
 \item{PC}{the predictor variables selected.}
 \item{anm.obj}{the \link{anm} object selected.}
 \item{coefficients}{the coeffecients of the \link{anm} object.}
 \item{step.min}{the number of steps which returns the minimum rmse.}
 \item{model}{the model corresponding to the minimum rmse.}
 \item{Rmse}{the minimum root mean square error.}
 \item{correlation}{the correlation between predictions and observations for the selected model.}
}
\note{
The running of the stepwise algorithm can be quite slow especially if the number of steps specified in the \emph{steps} argument is high.
}  
\author{Alexandra Imbert}
\seealso{\link{anm}, \link{predict.anm}}
\examples{
library(survival)
library(clim.pact)
data(susendal)
data(temp.era)
y<-susendal$V6 # temperatures
X<- eof$PC[,c(1,2,3)]
calibration <- c(susendal$V4>1979 & susendal$V4<1990 & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
evaluation <- c((susendal$V4>1990 & susendal$V4<1993 | susendal$V4==1990) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12))
y.calib <- y[calibration]
y.eval <- y[evaluation]
eof.calib <- c(eof$yy>1979 & eof$yy<1990)
eof.eval <- c(eof$yy> 1990 & eof$yy<1993| eof$yy==1990)
period <- c(calibration, evaluation)
y.period <- y[(susendal$V4>1979 & susendal$V4<1993) & (susendal$V3==1 | susendal$V3==2 | susendal$V3==12)]
test.data <-data.frame(y=y.period,
                       X1=X[eof$yy< 1993 & eof$yy> 1979,1],
                       X2=X[eof$yy< 1993 & eof$yy> 1979,2],
                       X3=X[eof$yy< 1993 & eof$yy> 1979,3],
                       yy=eof$yy[eof.calib | eof.eval],
                       mm=eof$mm[eof.calib | eof.eval],
                       dd=eof$dd[eof.calib | eof.eval])
test.anm<-anm(formula=y ~ X1 + X2 + X3,data=test.data)
stepANM(test.anm,steps=3)
}
\keyword{models}

\eof
\name{susendal}
\alias{susendal}
\title{Daily Susendal record.}
\description{
  A station record of daily mean temperature and daily precipitation from Susendal. 
}
\usage{data(susendal)}
\format{
The dataset is a data.frame containing:
   \item{V1}{station number.}
   \item{V2}{a vector holding day of month.}
   \item{V3}{a vector holding the month.}
   \item{V4}{a vector holding the year.}
   \item{V5}{a vector holding daily precipitation in mm.}
   \item{V6}{a vector holding daily mean temperature in deg C.}
      }
\source{The Norwegian Meteorological Institute, Climatology division.}
\references{
The Norwegian Meteorological Institute, P.O. Box 43, 0313 Oslo, Norway ({URL \url{http://www.met.no}})
}
\keyword{datasets}






\eof
\name{temp.era}
\alias{temp.era}
\title{Daily winter common EOF.}
\description{
  Common EOFs for daily December-February temperature. 
}
\usage{data(temp.era)}
\format{
\item{EOF}{EOF patterns.}
\item{W}{Eigen values.} 
\item{PC}{Principal components of common PCA.} 
\item{n.fld}{Number of different predictors (see \link[clim.pact]{mixFields}).} 
\item{tot.var}{ Sum of all W squared.} 
\item{id.t}{Time labels for the fields (see \link[clim.pact]{catFields}) - used in \link[clim.pact]{DS}. }
\item{id.x}{Spatial labels for the fields (see \link[clim.pact]{mixFields}) - used in \link[clim.pact]{plotEOF}.}
\item{mon}{Month (1-12) [season (1-4) for daily data] to extract.}
\item{id.lon}{Spatial labels for the fields (see \link[clim.pact]{mixFields}) - used in \link[clim.pact]{plotEOF}.}
\item{id.lat}{Spatial labels for the fields (see \link[clim.pact]{mixFields}) - used in \link[clim.pact]{plotEOF}.}
\item{region}{Describes the region analysed.}
\item{tim}{Time information (usually redundant).}
\item{lon}{Longitudes associated with EOF patterns.} 
\item{lat}{Latitudes associated with EOF patterns.} 
\item{var.eof}{Fractional variances associated with EOF patterns.} 
\item{yy}{years.} 
\item{mm}{months.}
\item{dd}{days.}
\item{v.name}{Name of element.} 
\item{c.mon}{Month-season information.}
\item{f.name}{File name of original data.} 
   }
\source{Rasmus E. Benestad \url{rasmus.benestad@met.no}.}
\references{
Reference to methodology: R.E. Benestad (2001), "A comparison between two empirical downscaling strategies", Int. J. Climatology, vol 210, pp.1645-1668. [DOI 10.1002/joc.703]. 
}
\keyword{datasets}



\eof
